@@ -13,15 +13,15 @@ def get_connection(host=None, port=None, sample_rate=None):
 
     return statsd.Connection(host, port, sample_rate)
 
+def get_client(name, connection=None, class_=statsd.Client):
+    if not connection:
+        connection = get_connection()
+
+    return class_(name, connection)
+
 def get_timer(name, connection=None):
-    if not connection:
-        connection = get_connection()
+    return get_client(name, connection, statsd.Timer)
 
-    return statsd.Timer(name, connection)
-
-def get_client(name, connection=None):
-    if not connection:
-        connection = get_connection()
-
-    return statsd.Client(name, connection)
+def get_counter(name, connection=None):
+    return get_client(name, connection, statsd.Counter)
 
